@@ -42,12 +42,10 @@ Authors:
 
 """
 
-from __future__ import with_statement, print_function
-
 __contact__ = "Jerome.Kieffer@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "Jérôme Kieffer"
-__date__ = "04/03/2019"
+__date__ = "11/12/2020"
 
 import time
 import logging
@@ -167,7 +165,7 @@ class OxdImage(FabioImage):
         # angle[0] = omega, angle[1] = theta, angle[2] = kappa, angle[3] = phi,
         start_angles_step = numpy.frombuffer(block[284:304], numpy.int32)
         end_angles_step = numpy.frombuffer(block[324:344], numpy.int32)
-        step2rad = numpy.frombuffer(block[368:408], numpy.float)
+        step2rad = numpy.frombuffer(block[368:408], numpy.float64)
         zero_correction_soft_step = numpy.frombuffer(block[512:532], numpy.int32)
         if not numpy.little_endian:
             start_angles_step.byteswap(True)
@@ -268,7 +266,6 @@ class OxdImage(FabioImage):
                 logger.info("Compressed with the TY5 compression")
                 dtype = numpy.dtype(numpy.int8)
                 raw8 = infile.read(dim1 * dim2)
-                raw_data = numpy.frombuffer(raw8, dtype)
 
                 if self.header['OI'] > 0:
                     self.raw16 = infile.read(self.header['OI'] * 2)
@@ -338,12 +335,12 @@ class OxdImage(FabioImage):
         header += NG.__repr__()
 
         NS = Section(self.header['Special Section size in Byte'], self.header)
-        NS.setData('Gain', 56, numpy.float)
+        NS.setData('Gain', 56, numpy.float64)
         NS.setData('Overflows flag', 464, numpy.int16)
         NS.setData('Overflow after remeasure flag', 466, numpy.int16)
         NS.setData('Overflow threshold', 472, numpy.int32)
-        NS.setData('Exposure time in sec', 480, numpy.float)
-        NS.setData('Overflow time in sec', 488, numpy.float)
+        NS.setData('Exposure time in sec', 480, numpy.float64)
+        NS.setData('Overflow time in sec', 488, numpy.float64)
         NS.setData('Monitor counts of raw image 1', 528, numpy.int32)
         NS.setData('Monitor counts of raw image 2', 532, numpy.int32)
         NS.setData('Monitor counts of overflow raw image 1', 536, numpy.int32)
@@ -353,8 +350,8 @@ class OxdImage(FabioImage):
             for key, value in DETECTOR_TYPES.items():
                 if value == self.header['Detector type']:
                     NS.setData(None, 548, numpy.int32, default=key)
-        NS.setData('Real pixel size x (mm)', 568, numpy.float)
-        NS.setData('Real pixel size y (mm)', 576, numpy.float)
+        NS.setData('Real pixel size x (mm)', 568, numpy.float64)
+        NS.setData('Real pixel size y (mm)', 576, numpy.float64)
         header += NS.__repr__()
 
         KM = Section(self.header['KM4 Section size in Byte'], self.header)
@@ -449,8 +446,8 @@ class OxdImage(FabioImage):
             self.header["Compression"] = "TY1"
 
         datablock8, datablock16, datablock32 = compTY1(self.data)
-        self.header["OI"] = len(datablock16) / 2
-        self.header["OL"] = len(datablock32) / 4
+        self.header["OI"] = len(datablock16) // 2
+        self.header["OL"] = len(datablock32) // 4
         with self._open(fname, mode="wb") as outfile:
             outfile.write(self._writeheader())
             outfile.write(datablock8)
@@ -528,6 +525,7 @@ class Section(object):
     """
     Small helper class for writing binary headers
     """
+
     def __init__(self, size, dictHeader):
         """
         :param size: size of the header section in bytes
@@ -543,7 +541,7 @@ class Section(object):
 
     def getSize(self, dtype):
         if dtype not in self._dictSize:
-            self._dictSize[dtype] = len(numpy.zeros(1, dtype=dtype).tostring())
+            self._dictSize[dtype] = len(numpy.zeros(1, dtype=dtype).tobytes())
         return self._dictSize[dtype]
 
     def setData(self, key, offset, dtype, default=None):
@@ -561,7 +559,7 @@ class Section(object):
         if value is None:
             value = b"\x00" * self.getSize(dtype)
         elif numpy.little_endian:
-            value = numpy.array(value).astype(dtype).tostring()
+            value = numpy.array(value).astype(dtype).tobytes()
         else:
-            value = numpy.array(value).astype(dtype).byteswap().tostring()
+            value = numpy.array(value).astype(dtype).byteswap().tobytes()
         self.lstChr[offset:offset + self.getSize(dtype)] = value
